@@ -27,16 +27,24 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.aws_iam
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-autoscaling-common.Alarms", jsii_struct_bases=[], name_mapping={'lower_alarm_interval_index': 'lowerAlarmIntervalIndex', 'upper_alarm_interval_index': 'upperAlarmIntervalIndex'})
-class Alarms():
-    def __init__(self, *, lower_alarm_interval_index: typing.Optional[jsii.Number]=None, upper_alarm_interval_index: typing.Optional[jsii.Number]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-autoscaling-common.Alarms",
+    jsii_struct_bases=[],
+    name_mapping={
+        "lower_alarm_interval_index": "lowerAlarmIntervalIndex",
+        "upper_alarm_interval_index": "upperAlarmIntervalIndex",
+    },
+)
+class Alarms:
+    def __init__(
+        self,
+        *,
+        lower_alarm_interval_index: typing.Optional[jsii.Number] = None,
+        upper_alarm_interval_index: typing.Optional[jsii.Number] = None,
+    ) -> None:
         """
         :param lower_alarm_interval_index: 
         :param upper_alarm_interval_index: 
@@ -44,10 +52,11 @@ class Alarms():
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if lower_alarm_interval_index is not None: self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
-        if upper_alarm_interval_index is not None: self._values["upper_alarm_interval_index"] = upper_alarm_interval_index
+        self._values = {}
+        if lower_alarm_interval_index is not None:
+            self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
+        if upper_alarm_interval_index is not None:
+            self._values["upper_alarm_interval_index"] = upper_alarm_interval_index
 
     @builtins.property
     def lower_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
@@ -55,7 +64,7 @@ class Alarms():
         stability
         :stability: experimental
         """
-        return self._values.get('lower_alarm_interval_index')
+        return self._values.get("lower_alarm_interval_index")
 
     @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
@@ -63,7 +72,7 @@ class Alarms():
         stability
         :stability: experimental
         """
-        return self._values.get('upper_alarm_interval_index')
+        return self._values.get("upper_alarm_interval_index")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -72,12 +81,20 @@ class Alarms():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'Alarms(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "Alarms(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-autoscaling-common.ArbitraryIntervals", jsii_struct_bases=[], name_mapping={'absolute': 'absolute', 'intervals': 'intervals'})
-class ArbitraryIntervals():
-    def __init__(self, *, absolute: bool, intervals: typing.List["ScalingInterval"]) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-autoscaling-common.ArbitraryIntervals",
+    jsii_struct_bases=[],
+    name_mapping={"absolute": "absolute", "intervals": "intervals"},
+)
+class ArbitraryIntervals:
+    def __init__(
+        self, *, absolute: bool, intervals: typing.List["ScalingInterval"]
+    ) -> None:
         """
         :param absolute: 
         :param intervals: 
@@ -86,8 +103,8 @@ class ArbitraryIntervals():
         :stability: experimental
         """
         self._values = {
-            'absolute': absolute,
-            'intervals': intervals,
+            "absolute": absolute,
+            "intervals": intervals,
         }
 
     @builtins.property
@@ -96,7 +113,7 @@ class ArbitraryIntervals():
         stability
         :stability: experimental
         """
-        return self._values.get('absolute')
+        return self._values.get("absolute")
 
     @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
@@ -104,7 +121,7 @@ class ArbitraryIntervals():
         stability
         :stability: experimental
         """
-        return self._values.get('intervals')
+        return self._values.get("intervals")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -113,12 +130,24 @@ class ArbitraryIntervals():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'ArbitraryIntervals(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "ArbitraryIntervals(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-autoscaling-common.CompleteScalingInterval", jsii_struct_bases=[], name_mapping={'lower': 'lower', 'upper': 'upper', 'change': 'change'})
-class CompleteScalingInterval():
-    def __init__(self, *, lower: jsii.Number, upper: jsii.Number, change: typing.Optional[jsii.Number]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-autoscaling-common.CompleteScalingInterval",
+    jsii_struct_bases=[],
+    name_mapping={"lower": "lower", "upper": "upper", "change": "change"},
+)
+class CompleteScalingInterval:
+    def __init__(
+        self,
+        *,
+        lower: jsii.Number,
+        upper: jsii.Number,
+        change: typing.Optional[jsii.Number] = None,
+    ) -> None:
         """
         :param lower: 
         :param upper: 
@@ -128,10 +157,11 @@ class CompleteScalingInterval():
         :stability: experimental
         """
         self._values = {
-            'lower': lower,
-            'upper': upper,
+            "lower": lower,
+            "upper": upper,
         }
-        if change is not None: self._values["change"] = change
+        if change is not None:
+            self._values["change"] = change
 
     @builtins.property
     def lower(self) -> jsii.Number:
@@ -139,7 +169,7 @@ class CompleteScalingInterval():
         stability
         :stability: experimental
         """
-        return self._values.get('lower')
+        return self._values.get("lower")
 
     @builtins.property
     def upper(self) -> jsii.Number:
@@ -147,7 +177,7 @@ class CompleteScalingInterval():
         stability
         :stability: experimental
         """
-        return self._values.get('upper')
+        return self._values.get("upper")
 
     @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
@@ -155,7 +185,7 @@ class CompleteScalingInterval():
         stability
         :stability: experimental
         """
-        return self._values.get('change')
+        return self._values.get("change")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -164,7 +194,9 @@ class CompleteScalingInterval():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CompleteScalingInterval(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CompleteScalingInterval(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-autoscaling-common.IRandomGenerator")
@@ -173,6 +205,7 @@ class IRandomGenerator(jsii.compat.Protocol):
     stability
     :stability: experimental
     """
+
     @builtins.staticmethod
     def __jsii_proxy_class__():
         return _IRandomGeneratorProxy
@@ -197,12 +230,14 @@ class IRandomGenerator(jsii.compat.Protocol):
         ...
 
 
-class _IRandomGeneratorProxy():
+class _IRandomGeneratorProxy:
     """
     stability
     :stability: experimental
     """
+
     __jsii_type__ = "@aws-cdk/aws-autoscaling-common.IRandomGenerator"
+
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> bool:
         """
@@ -223,9 +258,19 @@ class _IRandomGeneratorProxy():
         return jsii.invoke(self, "nextInt", [min, max])
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-autoscaling-common.ScalingInterval", jsii_struct_bases=[], name_mapping={'change': 'change', 'lower': 'lower', 'upper': 'upper'})
-class ScalingInterval():
-    def __init__(self, *, change: jsii.Number, lower: typing.Optional[jsii.Number]=None, upper: typing.Optional[jsii.Number]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-autoscaling-common.ScalingInterval",
+    jsii_struct_bases=[],
+    name_mapping={"change": "change", "lower": "lower", "upper": "upper"},
+)
+class ScalingInterval:
+    def __init__(
+        self,
+        *,
+        change: jsii.Number,
+        lower: typing.Optional[jsii.Number] = None,
+        upper: typing.Optional[jsii.Number] = None,
+    ) -> None:
         """A range of metric values in which to apply a certain scaling operation.
 
         :param change: The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
@@ -236,10 +281,12 @@ class ScalingInterval():
         :stability: experimental
         """
         self._values = {
-            'change': change,
+            "change": change,
         }
-        if lower is not None: self._values["lower"] = lower
-        if upper is not None: self._values["upper"] = upper
+        if lower is not None:
+            self._values["lower"] = lower
+        if upper is not None:
+            self._values["upper"] = upper
 
     @builtins.property
     def change(self) -> jsii.Number:
@@ -257,7 +304,7 @@ class ScalingInterval():
         stability
         :stability: experimental
         """
-        return self._values.get('change')
+        return self._values.get("change")
 
     @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
@@ -271,7 +318,7 @@ class ScalingInterval():
         stability
         :stability: experimental
         """
-        return self._values.get('lower')
+        return self._values.get("lower")
 
     @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
@@ -285,7 +332,7 @@ class ScalingInterval():
         stability
         :stability: experimental
         """
-        return self._values.get('upper')
+        return self._values.get("upper")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -294,7 +341,9 @@ class ScalingInterval():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'ScalingInterval(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "ScalingInterval(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
